package BOKUTIN::FatalsToEmail;
# ABSTRACT: CGI::Carp 'fatalsToBrowser' のスクリプト版
$BOKUTIN::FatalsToEmail::VERSION = '0.142361';
use strict;
use warnings;

sub import {
    my $class = shift;
    my $opts = do {
        if (@_ == 1 and !ref $_[0]) {
            +{ to => $_[0] };
        }
        else {
            +{ @_ };
        }
    };

    if ($main::SIG{__DIE__}) {
        warn "@{[ __PACKAGE__ ]} override \$main::SIG{__DIE__}.";
    }

    $main::SIG{__DIE__} = sub {
        my $err = shift;

        system("tty -s");
        if ($? == 0) {
            # STDIN is a terminal
            die $err;
        }
        elsif ($? == -1) {
            # tty is not found.
        }
        elsif ($? == 1) {
            # STDIN is not a terminal
        }
        else {
            # an error occurs
        }

        require Exception::Reporter;
        require Exception::Reporter::Sender::Email;
        require Exception::Reporter::Summarizer::Email;
        require Exception::Reporter::Summarizer::File;
        require Exception::Reporter::Summarizer::ExceptionClass;
        require Exception::Reporter::Summarizer::Fallback;
        require Exception::Reporter::Dumper::HTML;
        require Exception::Reporter::Summarizer::DevelStackTrace;

        my $reporter = Exception::Reporter->new({
            always_dump => {
                env => sub { \%ENV },
            },
            dumper => Exception::Reporter::Dumper::HTML->new,
            senders     => [
                Exception::Reporter::Sender::Email->new({
                    from => $opts->{from} || $ENV{USER},
                    to   => $opts->{to}   || 'bokutin@bokut.in',
                }),
            ],
            summarizers => [
                Exception::Reporter::Summarizer::Email->new,
                Exception::Reporter::Summarizer::File->new,
                Exception::Reporter::Summarizer::ExceptionClass->new,
                Exception::Reporter::Summarizer::DevelStackTrace->new,

                Exception::Reporter::Summarizer::Fallback->new,
            ],
        });

        require Devel::StackTrace::WithLexicals;
        my $trace = Devel::StackTrace::WithLexicals->new;

        require Sys::Hostname;
        my $host = Sys::Hostname::hostname();

        $reporter->report_exception(
            [
                #[ exception => $err ],
                [ trace     => $trace ],
            ],
            {
                handled  => 1,
                reporter => "[FatalsToEmail] $host:$0",
            },
        );

        die $err;
    };
}

1;

__END__

=pod

=head1 NAME

BOKUTIN::FatalsToEmail - CGI::Carp 'fatalsToBrowser' のスクリプト版

=head1 VERSION

version 0.142361

=head1 AUTHOR

Tomohiro Hosaka <bokutin@bokut.in>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Tomohiro Hosaka.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
