package Exception::Reporter::Dumper::HTML;
$Exception::Reporter::Dumper::HTML::VERSION = '0.142361';
use strict;
use warnings;
use parent 'Exception::Reporter::Dumper';

use Try::Tiny;
use Data::Dumper;

sub _ident_from {
    my ($self, $str, $x) = @_;

    $str =~ s/\A\n+//;
    ($str) = split /\n/, $str;

    unless (defined $str and length $str and $str =~ /\S/) {
        $str = sprintf "<<unknown%s>>", $x ? ' ($x)' : '';
    }

    return $str;
}

sub dump {
    my ($self, $value, $arg) = @_;
    my $basename = $arg->{basename} || 'dump';

    my $ident = ref $value     ? (try { "$value" } catch { "<unknown>" })
              : defined $value ? "$value" # quotes in case of glob, vstr, etc.
              :                  "(undef)";

    $ident = $self->_ident_from($ident);

    require Data::Format::Pretty::HTML;
    my $dump = Data::Format::Pretty::HTML::format_pretty($value);

    return (
        {
            mimetype => 'text/html',
            ident    => $ident,
            body     => $dump,
        },
    );
}

1;

__END__

=pod

=head1 NAME

Exception::Reporter::Dumper::HTML

=head1 VERSION

version 0.142361

=head1 AUTHOR

Tomohiro Hosaka <bokutin@bokut.in>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Tomohiro Hosaka.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
