package Exception::Reporter::Summarizer::DevelStackTrace;
$Exception::Reporter::Summarizer::DevelStackTrace::VERSION = '0.142361';
use strict;
use warnings;
use parent 'Exception::Reporter::Summarizer';

use Try::Tiny;

sub can_summarize {
    my ($self, $entry) = @_;
    return try { $entry->[1]->isa('Devel::StackTrace') };
}

sub summarize {
    my ($self, $entry, $internal_arg) = @_;
    my ($name, $trace, $arg) = @$entry;

    require Devel::StackTrace::AsHTML;

    my $ident = $trace->as_string;
    ($ident) = split /\n/, $ident; # only the first line, please

    # http://cpansearch.perl.org/src/MIYAGAWA/Plack-1.0031/lib/Plack/Middleware/StackTrace.pm
    my @summaries = (
        {
            #filename => "stacktrace.html",
            mimetype => 'text/html',
            ident    => $ident,
            body     => $trace->as_html,
        },
        {
            filename => "stacktrace.txt",
            mimetype => 'text/plain',
            ident    => $ident,
            body     => $trace->as_string,
        },
    );

    return @summaries;
}

1;

__END__

=pod

=head1 NAME

Exception::Reporter::Summarizer::DevelStackTrace

=head1 VERSION

version 0.142361

=head1 AUTHOR

Tomohiro Hosaka <bokutin@bokut.in>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Tomohiro Hosaka.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
